# nytid

Manage TA bookings, schedules, time tracking, and task management for teaching.

For an introduction and overview, read Chapter 1 in the PDF found in the latest 
[release](https://github.com/dbosk/nytid/releases).
